@@ -20,24 +20,23 @@
 #' }
 #'
 #'
-#' @source \url{https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html}
+#' @source <https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html>
 "sentiments"
 
-
 #' Get a tidy data frame of a single sentiment lexicon
 #'
 #' Get specific sentiment lexicons in a tidy format, with one row per word,
 #' in a form that can be joined with a one-word-per-row dataset.
-#' The \code{"bing"} option comes from the included \code{\link{sentiments}}
+#' The `"bing"` option comes from the included [sentiments()]
 #' data frame, and others call the relevant function in the \pkg{textdata}
 #' package.
 #'
 #' @param lexicon The sentiment lexicon to retrieve;
 #' either "afinn", "bing", "nrc", or "loughran"
 #'
-#' @return A tbl_df with a \code{word} column, and either a \code{sentiment}
-#' column (if \code{lexicon} is not "afinn") or a numeric \code{value} column
-#' (if \code{lexicon} is "afinn").
+#' @return A tbl_df with a `word` column, and either a `sentiment`
+#' column (if `lexicon` is not "afinn") or a numeric `value` column
+#' (if `lexicon` is "afinn").
 #'
 #' @examples
 #'
@@ -54,9 +53,11 @@
 get_sentiments <- function(lexicon = c("bing", "afinn", "loughran", "nrc")) {
   lexicon <- match.arg(lexicon)
 
-  lexicon_names <- list(afinn    = "AFINN",
-                        loughran = "Loughran-McDonald",
-                        nrc      = "NRC word-emotion association")
+  lexicon_names <- list(
+    afinn = "AFINN",
+    loughran = "Loughran-McDonald",
+    nrc = "NRC word-emotion association"
+  )
 
   if (lexicon != "bing" && !requireNamespace("textdata", quietly = TRUE)) {
     msg <- "The textdata package is required to download the {lexicon_names[[lexicon]]} lexicon.\nInstall the textdata package to access this dataset."
@@ -65,10 +66,10 @@ get_sentiments <- function(lexicon = c("bing", "afinn", "loughran", "nrc")) {
 
   switch(
     lexicon,
-    afinn    = textdata::lexicon_afinn(),
-    nrc      = textdata::lexicon_nrc(),
+    afinn = textdata::lexicon_afinn(),
+    nrc = textdata::lexicon_nrc(),
     loughran = textdata::lexicon_loughran(),
-    bing     = tidytext::sentiments,
+    bing = tidytext::sentiments,
     stop("Unexpected lexicon", call. = FALSE)
   )
 }
