@@ -8,7 +8,7 @@
 #' @inheritParams unnest_tokens
 #' @inheritParams tokenizers::tokenize_regex
 #'
-#' @param ... Extra arguments passed on to \link[tokenizers]{tokenizers}
+#' @param ... Extra arguments passed on to [tokenizers][tokenizers::tokenizers]
 #'
 #' @export
 #' @importFrom dplyr enquo
@@ -32,17 +32,18 @@ unnest_regex <- function(
   drop = TRUE,
   collapse = NULL,
   ...
-){
-  format <- match.arg(format)
-  unnest_tokens(tbl,
-                !! enquo(output),
-                !! enquo(input),
-                token = "regex",
-                format = format,
-                to_lower = to_lower,
-                drop = drop,
-                collapse = collapse,
-                pattern = pattern,
-                ...
+) {
+  format <- arg_match(format)
+  unnest_tokens(
+    tbl,
+    !!enquo(output),
+    !!enquo(input),
+    token = "regex",
+    format = format,
+    to_lower = to_lower,
+    drop = drop,
+    collapse = collapse,
+    pattern = pattern,
+    ...
   )
 }
