@@ -1,9 +1,9 @@
-
 test_that("Can tidy DocumentTermMatrices and TermDocumentMatrices", {
   if (require("tm", quietly = TRUE)) {
     txt <- system.file("texts", "txt", package = "tm")
-    ovid <- VCorpus(DirSource(txt, encoding = "UTF-8"),
-                    readerControl = list(language = "lat")
+    ovid <- VCorpus(
+      DirSource(txt, encoding = "UTF-8"),
+      readerControl = list(language = "lat")
     )
 
     ovid_dtm <- DocumentTermMatrix(ovid)
@@ -22,7 +22,6 @@ test_that("Can tidy DocumentTermMatrices and TermDocumentMatrices", {
   }
 })
 
-
 test_that("Can tidy dfm from quanteda", {
   if (requireNamespace("quanteda", quietly = TRUE)) {
     dfm_obj <- quanteda::dfm(quanteda::tokens(quanteda::data_corpus_inaugural))
