@@ -1,14 +1,28 @@
-context("tf-idf calculation")
-
 w <- tibble(
   document = rep(1:2, each = 5),
   word = c(
-    "the", "quick", "brown", "fox", "jumped",
-    "over", "the", "lazy", "brown", "dog"
+    "the",
+    "quick",
+    "brown",
+    "fox",
+    "jumped",
+    "over",
+    "the",
+    "lazy",
+    "brown",
+    "dog"
   ),
   frequency = c(
-    1, 1, 1, 1, 2,
-    1, 1, 1, 1, 2
+    1,
+    1,
+    1,
+    1,
+    2,
+    1,
+    1,
+    1,
+    1,
+    2
   )
 )
 
@@ -24,10 +38,10 @@ test_that("Can calculate TF-IDF", {
     select(result, document, word, frequency)
   )
 
-  expect_is(result, "tbl_df")
-  expect_is(result$tf, "numeric")
-  expect_is(result$idf, "numeric")
-  expect_is(result$tf_idf, "numeric")
+  expect_s3_class(result, "tbl_df")
+  expect_type(result$tf, "double")
+  expect_type(result$idf, "double")
+  expect_type(result$tf_idf, "double")
 
   expect_equal(result$tf, rep(c(1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 3), 2))
   expect_equal(result$idf[1:4], c(0, log(2), 0, log(2)))
@@ -42,7 +56,6 @@ test_that("Can calculate TF-IDF", {
   expect_equal(as.character(groups(result2)[[1]]), "document")
 })
 
-
 test_that("TF-IDF works when the document ID is a number", {
   # example thanks to https://github.com/juliasilge/tidytext/issues/31
   my_corpus <- dplyr::tibble(
@@ -56,12 +69,13 @@ test_that("TF-IDF works when the document ID is a number", {
   expect_equal(tf_idf$tf_idf[c(3, 6)], c(0, 0))
 })
 
-
 test_that("tf-idf with tidyeval works", {
-  d <- tibble(txt = c(
-    "Because I could not stop for Death -",
-    "He kindly stopped for me -"
-  ))
+  d <- tibble(
+    txt = c(
+      "Because I could not stop for Death -",
+      "He kindly stopped for me -"
+    )
+  )
   termvar <- quo("word")
   documentvar <- quo("document")
   countvar <- quo("frequency")
@@ -74,10 +88,10 @@ test_that("tf-idf with tidyeval works", {
     select(result, document, word, frequency)
   )
 
-  expect_is(result, "tbl_df")
-  expect_is(result$tf, "numeric")
-  expect_is(result$idf, "numeric")
-  expect_is(result$tf_idf, "numeric")
+  expect_s3_class(result, "tbl_df")
+  expect_type(result$tf, "double")
+  expect_type(result$idf, "double")
+  expect_type(result$tf_idf, "double")
 
   expect_equal(result$tf, rep(c(1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 3), 2))
   expect_equal(result$idf[1:4], c(0, log(2), 0, log(2)))
